* project: economic inequality and democratic support (JOP)
* filename: JOP1.do
* what this do-file does: preparing the data up to imputation

*FILE SETUP
*Create a directory with a name of your choice
*Place all original data files and all code files into that directory
*Create a subdirectory in that directory called "data"

clear
set memory 900m, perm
* the integrated WVS dataset is huge, so we need more memory than 256m, which is the default setting of STATA.
* drop ",perm" above if you don't want to permanently increase the memory allocated to STATA.
capture log close
set more off

*World Values Survey Data  

* globals
** Hence I will name the directory for the given data "dir" and that for generated data "data"

* the following globals are for the authors but might serve as examples for readers.
*SON GLOBALS
*global dir "E:\Inequality\2013"
*global data "E:\Inequality\2013\data"
*global dir "K:\Inequality\2013"
*global data "K:\Inequality\2013\data"
*global dir "K:\Inequality\2011\dir"
*global data "K:\Inequality\2011\data"
*global dir "E:\Inequality\2011\dir"
*global data "E:\Inequality\2011\data"

*KRIECKHAUS GLOBALS
global dir "U:\Research\Publications\Wells (2)\JOP\Statistics"
global data "U:\Research\Publications\Wells (2)\JOP\Statistics\Data"

**********************************************************************************************************

* Task I: Level 1 data (WVS)

* we use "WVS five-wave aggregated file 1981-2005" which is available at http://www.wvsevsdb.com/wvs/WVSData.jsp
* download the stata file and save it in "dir" as "wvs_full"

clear
set more off
cd "$dir"
use wvs_full
cd "$data"


*1. GENERATE THE DEMOCRATIC SUPPORT VARIABLE

gen wave = s002
keep if wave > 2

*First two variables are reversed in scale to make intuitive sense (greater value corresponds to more support for democracy)
** v157 is e117 in the integrated version
gen my157 =e117
recode my157 1=3 2=2 3=1 4=0
** v163 is e123 in the integrated version
gen my163 = e123
recode my163 1=3 2=2 3=1 4=0
gen support = my157 + my163
** v154 is e114 in the integrated version
gen my154 = e114
recode my154 1=0 2=1 3=2 4=3
** v156 is e116 in the integrated version
gen my156 = e116
recode my156 1=0 2=1 3=2 4=3
gen antiauth=my154 + my156
gen sa = support + antiauth

*2. RENAME AND RECODING OTHER WVS VARIABLES

gen trust = a165
recode trust 1=1 2=0
label var trust "Interpersonal Trust"

gen econsat = c006
label var econsat "Financial Satis."

gen interest = e023
recode interest 4=1 3=2 2=3 1=4

gen ideo = e033
label var ideo "Left Ideology"
recode ideo 10=1 9=2 8=3 7=4 6=5 5=6 4=7 3=8 2=9 1=10

*institutional confidence
*national government
gen natgov = e069_11
recode natgov 4=0 3=1 2=2 1=3
label var natgov "confidence in national government"
*political parties
gen party = e069_12
recode party 4=0 3=1 2=2 1=3
label var e069_12 "confidence in political parties"
*parliament
gen parl =  e069_07
recode parl 4=0 3=1 2=2 1=3
label var parl "confidence in parliament"
*civil service
gen civil =  e069_08
recode civil 4=0 3=1 2=2 1=3
label var civil "confidence in civil service"

gen instconf = (natgov + party + parl + civil)
label var instconf "Institutional Confidence"

gen retpol = e112
label var retpol "Prior Regime Support"

gen polexp = e113
label var polexp "Regime expectation"

gen current = e111
label var current "current regime support"

gen male = x001
recode male 1=1 2=0
label var male "Gender: female = 0, male=1"

gen age = x003 
label var age "Age"

gen edu = x025
label var edu "Education"

gen class = x045
label var class "Social Class"
recode class 5=1 4=2 3=3 2=4 1=5

gen income = x047
label var income "Income"

save temp1_1, replace


save temp2_2, replace

*3. GENERATE WVS_TRUNCATE DATASET (and prepare it for merging)
keep s003 s020 wave-ctyr
rename s020 year

gen country = "."
replace country = "Albania"	if s003 ==	8
replace country = "Algeria"	if s003 ==	12
replace country = "Argentina"	if s003 ==	32
replace country = "Bangladesh"	if s003 ==	50
replace country = "Bosnia And Herzegovina"	if s003 ==	70
replace country = "Canada"	if s003 ==	124
replace country = "Chile"	if s003 ==	152
replace country = "China"	if s003 ==	156
replace country = "India"	if s003 ==	356
replace country = "Indonesia"	if s003 ==	360
replace country = "Iran"	if s003 ==	364
replace country = "Iraq"	if s003 ==	368
replace country = "Japan"	if s003 ==	392
replace country = "Jordan"	if s003 ==	400
replace country = "South Korea"	if s003 ==	410
replace country = "Kyrgyzstan"	if s003 ==	417
replace country = "Mexico"	if s003 ==	484
replace country = "Moldova"	if s003 ==	498
replace country = "Morocco"	if s003 ==	504
replace country = "Nigeria"	if s003 ==	566
replace country = "Pakistan"	if s003 ==	586
replace country = "Peru"	if s003 ==	604
replace country = "Philippines"	if s003 ==	608
replace country = "Puerto Rico"	if s003 ==	630
replace country = "Viet Nam"	if s003 ==	704
replace country = "South Africa"	if s003 ==	710
replace country = "Zimbabwe"	if s003 ==	716
replace country = "Spain"	if s003 ==	724
replace country = "Sweden"	if s003 ==	752
replace country = "Turkey"	if s003 ==	792
replace country = "Uganda"	if s003 ==	800
replace country = "Macedonia"	if s003 ==	807
replace country = "Tanzania"	if s003 ==	834
replace country = "United States"	if s003 ==	840
replace country = "Venezuela"	if s003 ==	862
replace country = "Serbia And Montenegro"	if s003 ==	891
replace country = 	"Armenia" if s003 == 51
replace country = 	"Australia" if s003 == 36
replace country = 	"Azerbaijan" if s003 == 31
replace country = 	"Belarus" if s003 == 112
replace country = 	"Brazil" if s003 ==  76
replace country = 	"Bulgaria" if s003 == 100
replace country = 	"Croatia" if s003 == 191
replace country = 	"Czech Rep." if s003 == 203
replace country = 	"Dominican Rep" if s003 == 	214
replace country = 	"Estonia" if s003 == 233
replace country = 	"Finland" if s003 == 246
replace country = 	"Georgia" if s003 == 268
replace country = 	"Germany" if s003 == 276
replace country = 	"Guatemala" if s003 == 320
replace country = 	"Hong Kong" if s003 == 344
replace country = 	"Hungary" if s003 == 348
replace country = 	"Latvia" if s003 == 428
replace country = 	"Lithuania" if s003 == 440
replace country = 	"New Zealand" if s003 == 554
replace country = 	"Norway" if s003 == 578
replace country = 	"Romania" if s003 == 642
replace country = 	"Russia" if s003 == 643
replace country = 	"Slovakia" if s003 == 703
replace country = 	"Slovenia" if s003 == 705
replace country = 	"Switzerland" if s003 == 756
replace country = 	"Taiwan" if s003 == 158
replace country = 	"Ukraine" if s003 == 804
replace country = 	"Uruguay" if s003 == 858
drop s003
cd "$dir"
run code.do
cd "$data"
gen match = year*1000 + code
gen id=_n

sort match
label data "wvs 3-4-5 (truncated)"
save wvs_3_4_5, replace


**********************************************************************************************


*Task II: getting Level-2 data.

* the data we will use are
* 1) Cheibub et al(2009) data (ACLP): save the .dta file as "cheibub" in "dir"
* 2) POLITY IV: save the .dta file as "polity" in "dir" 
* 3) SWIID: save the .dta file as "swiidv1_1" in "dir"
* 4) SIID: save the .dta file as "2006sidd-3-aug21" in "dir"
* 5) macroeconomic data (GDP growth rate and GDP per capita from WDI): save the .dta file (2011 version) as "wdi2011" in "dir"

* 1. Cheibub et al. data (2009)
clear
cd "$dir"
use cheibub

keep country year democracy regime agedem aclp_region
label var democracy "1=demo, 2=auth"
label var agedem "age of democracy"
gen region = 0
recode region 0=1 if aclp_region == 1
recode region 0=2 if aclp_region == 2
recode region 0=2 if aclp_region == 3
recode region 0=2 if aclp_region == 4
recode region 0=3 if aclp_region == 7
recode region 0=3 if aclp_region == 8
recode region 0=4 if aclp_region == 9
recode region 0=5 if aclp_region == 6
recode region 0=5 if aclp_region == 11
recode region 0=6 if aclp_region == 10
label var region "1=Afr/2=Asia/3=LA/4=EE/5=ME/6=OECD/0=others"
drop aclp_region

run code.do
drop if code==.
gen match = year*1000+code
cd "$data"
sort match
save cheibub, replace 

* 2. polity
clear
cd "$dir"
use polity
drop if year<1960
run code
gen match = year*1000 + code
dups match, drop
drop _expand
xtset code year
gen transition = 0
recode transition 0=1 if l.polity2<6 & polity>=6
label variable transition "first year of democratization using polity2>=6"

* now generating a counting variable
gen temp01=transition
replace temp01=0 if transition==.
* such that missing values don't mark a beginning of a democratization episode
recode temp01 0=1 1=0
by code: egen minyear = min(year) if (temp01 !=.)
gen temp02 = .
by code:replace temp02 = 0 if year == minyear 
by code:replace temp02 = temp01*(temp02[_n-1] + temp01[_n-1]) if year>minyear
by code:replace temp02 = temp02 + 1 if temp01 == 1
rename temp02 age_demo_pol
gen lage_pol = log(age_demo_pol)
label variable lage_pol "log of age of democracy, polity"
drop temp01  minyear

sort match
cd "$data"
save polity, replace

* 3. gini1, gini2 (swiid)
clear
cd "$dir"
use swiidv1_1
run code
drop if code==.
gen match = year*1000 + code
xtset code year
gen gini5 = l5.gini_net
gen gini10 = l10.gini_net
drop country
sort match
cd "$data"
save gini12, replace


* 4. gini (SIID)
clear
cd "$dir"

use 2006sidd-3-aug21
keep  year code gini_bes


gen country="missing"
replace country=	"Afghanistan"  if code=="AFG"
replace country=	"Albania"  if code=="ALB"
replace country=	"Algeria"  if code=="DZA"
replace country=	"Andorra"  if code=="ADO"
replace country=	"Angola"  if code=="AGO"
replace country=	"Antigua & Barbuda"  if code=="ATG"
replace country=	"Argentina"  if code=="ARG"
replace country=	"Armenia"  if code=="ARM"
replace country=	"Australia"  if code=="AUS"
replace country=	"Austria"  if code=="AUT"
replace country=	"Azerbaijan"  if code=="AZE"
replace country=	"Bahamas"  if code=="BHS"
replace country=	"Bahrain"  if code=="BHR"
replace country=	"Bangladesh"  if code=="BGD"
replace country=	"Barbados"  if code=="BRB"
replace country=	"Belarus"  if code=="BLR"
replace country=	"Belgium"  if code=="BEL"
replace country=	"Belize"  if code=="BLZ"
replace country=	"Benin"  if code=="BEN"
replace country=	"Bhutan"  if code=="BTN"
replace country=	"Bolivia"  if code=="BOL"
replace country=	"Bosnia and Herzegovina"  if code=="BIH"
replace country=	"Botswana"  if code=="BWA"
replace country=	"Brazil"  if code=="BRA"
replace country=	"Brunei Darussalam"  if code=="BRN"
replace country=	"Bulgaria"  if code=="BGR"
replace country=	"Burkina Faso"  if code=="BFA"
replace country=	"Burundi"  if code=="BDI"
replace country=	"Cambodia"  if code=="KHM"
replace country=	"Cameroon"  if code=="CMR"
replace country=	"Canada"  if code=="CAN"
replace country=	"Cape Verde"  if code=="CPV"
replace country=	"Central African Republic"  if code=="CAF"
replace country=	"Chad"  if code=="TCD"
replace country=	"Chile"  if code=="CHL"
replace country=	"China"  if code=="CHN"
replace country=	"Colombia"  if code=="COL"
replace country=	"Comoros"  if code=="COM"
replace country=	"Congo (Brazzaville, Republic of Congo)"  if code=="COG"
replace country=	"Costa Rica"  if code=="CRI"
replace country=	"Cote d'Ivoire"  if code=="CIV"
replace country=	"Croatia"  if code=="HRV"
replace country=	"Cuba"  if code=="CUB"
replace country=	"Cyprus"  if code=="CYP"
replace country=	"Czech Republic"  if code=="CZE"
replace country=	"Democratic Republic of the Congo (Zaire, Congo-Kinshasha)"  if code=="ZAR"
replace country=	"Denmark"  if code=="DNK"
replace country=	"Djibouti"  if code=="DJI"
replace country=	"Dominica"  if code=="DMA"
replace country=	"Dominican Republic"  if code=="DOM"
replace country=	"Ecuador"  if code=="ECU"
replace country=	"Egypt"  if code=="EGY"
replace country=	"El Salvador"  if code=="SLV"
replace country=	"Equatorial Guinea"  if code=="GNQ"
replace country=	"Eritrea"  if code=="ERI"
replace country=	"Estonia"  if code=="EST"
replace country=	"Ethiopia"  if code=="ETH"
replace country=	"Fiji"  if code=="FJI"
replace country=	"Finland"  if code=="FIN"
replace country=	"France"  if code=="FRA"
replace country=	"Gabon"  if code=="GAB"
replace country=	"Gambia"  if code=="GMB"
replace country=	"Georgia"  if code=="GEO"
replace country=	"Germany"  if code=="DEU"
replace country=	"Ghana"  if code=="GHA"
replace country=	"Greece"  if code=="GRC"
replace country=	"Grenada"  if code=="GRD"
replace country=	"Guatemala"  if code=="GTM"
replace country=	"Guinea"  if code=="GIN"
replace country=	"Guinea-Bissau"  if code=="GNB"
replace country=	"Guyana"  if code=="GUY"
replace country=	"Haiti"  if code=="HTI"
replace country=	"Honduras"  if code=="HND"
replace country=	"Hungary"  if code=="HUN"
replace country=	"Iceland"  if code=="ISL"
replace country=	"India"  if code=="IND"
replace country=	"Indonesia"  if code=="IDN"
replace country=	"Iran"  if code=="IRN"
replace country=	"Iraq"  if code=="IRQ"
replace country=	"Ireland"  if code=="IRL"
replace country=	"Israel"  if code=="ISR"
replace country=	"Italy"  if code=="ITA"
replace country=	"Jamaica"  if code=="JAM"
replace country=	"Japan"  if code=="JPN"
replace country=	"Jordan"  if code=="JOR"
replace country=	"Kazakhstan"  if code=="KAZ"
replace country=	"Kenya"  if code=="KEN"
replace country=	"Kiribati"  if code=="KIR"
replace country=	"Kuwait"  if code=="KWT"
replace country=	"Kyrgyzstan"  if code=="KGZ"
replace country=	"Laos"  if code=="LAO"
replace country=	"Latvia"  if code=="LVA"
replace country=	"Lebanon"  if code=="LBN"
replace country=	"Lesotho"  if code=="LSO"
replace country=	"Liberia"  if code=="LBR"
replace country=	"Libyan Arab Jamahiriya"  if code=="LBY"
replace country=	"Liechtenstein"  if code=="LIE"
replace country=	"Lithuania"  if code=="LTU"
replace country=	"Luxembourg"  if code=="LUX"
replace country=	"Macedonia"  if code=="MKD"
replace country=	"Madagascar"  if code=="MDG"
replace country=	"Malawi"  if code=="MWI"
replace country=	"Malaysia"  if code=="MYS"
replace country=	"Maldives"  if code=="MDV"
replace country=	"Mali"  if code=="MLI"
replace country=	"Malta"  if code=="MLT"
replace country=	"Marshall Islands"  if code=="MHL"
replace country=	"Mauritania"  if code=="MRT"
replace country=	"Mauritius"  if code=="MUS"
replace country=	"Mexico"  if code=="MEX"
replace country=	"Micronesia, Federated States of"  if code=="FSM"
replace country=	"Moldova"  if code=="MDA"
replace country=	"Mongolia"  if code=="MNG"
replace country=	"Morocco"  if code=="MAR"
replace country=	"Mozambique"  if code=="MOZ"
replace country=	"Myanmar"  if code=="MMR"
replace country=	"Namibia"  if code=="NAM"
replace country=	"Nauru"  if code==""
replace country=	"Nepal"  if code=="NPL"
replace country=	"Netherlands"  if code=="NLD"
replace country=	"New Zealand"  if code=="NZL"
replace country=	"Nicaragua"  if code=="NIC"
replace country=	"Niger"  if code=="NER"
replace country=	"Nigeria"  if code=="NGA"
replace country=	"North Korea"  if code=="PRK"
replace country=	"Norway"  if code=="NOR"
replace country=	"Oman"  if code=="OMN"
replace country=	"Pakistan"  if code=="PAK"
replace country=	"Palau"  if code=="PLW"
replace country=	"Panama"  if code=="PAN"
replace country=	"Papua New Guinea"  if code=="PNG"
replace country=	"Paraguay"  if code=="PRY"
replace country=	"Peru"  if code=="PER"
replace country=	"Philippines"  if code=="PHL"
replace country=	"Poland"  if code=="POL"
replace country=	"Portugal"  if code=="PRT"
replace country=	"Qatar"  if code=="QAT"
replace country=	"Romania"  if code=="ROM"
replace country=	"Russian Federation"  if code=="RUS"
replace country=	"Rwanda"  if code=="RWA"
replace country=	"Samoa"  if code=="WSM"
replace country=	"San Marino"  if code=="SMR"
replace country=	"Sao Tome and Principe"  if code=="STP"
replace country=	"Saudi Arabia"  if code=="SAU"
replace country=	"Senegal"  if code=="SEN"
replace country=	"Serbia and Montenegro"  if code=="YUG"
replace country=	"Seychelles"  if code=="SYC"
replace country=	"Sierra Leone"  if code=="SLE"
replace country=	"Singapore"  if code=="SGP"
replace country=	"Slovakia"  if code=="SVK"
replace country=	"Slovenia"  if code=="SVN"
replace country=	"Solomon Islands"  if code=="SLB"
replace country=	"Somalia"  if code=="SOM"
replace country=	"South Africa"  if code=="ZAF"
replace country=	"South Korea"  if code=="KOR"
replace country=	"Spain"  if code=="ESP"
replace country=	"Sri Lanka"  if code=="LKA"
replace country=	"St. Kitts and Nevis"  if code=="KNA"
replace country=	"St. Lucia"  if code=="LCA"
replace country=	"St. Vincent and the Grenadines"  if code=="VCT"
replace country=	"Sudan"  if code=="SDN"
replace country=	"Suriname"  if code=="SUR"
replace country=	"Swaziland"  if code=="SWZ"
replace country=	"Sweden"  if code=="SWE"
replace country=	"Switzerland"  if code=="CHE"
replace country=	"Syria"  if code=="SYR"
replace country=	"Taiwan"  if code=="TWN"
replace country=	"Tajikistan"  if code=="TJK"
replace country=	"Tanzania"  if code=="TZA"
replace country=	"Thailand"  if code=="THA"
replace country=	"Togo"  if code=="TGO"
replace country=	"Tonga"  if code=="TON"
replace country=	"Trinidad and Tobago"  if code=="TTO"
replace country=	"Tunisia"  if code=="TUN"
replace country=	"Turkey"  if code=="TUR"
replace country=	"Turkmenistan"  if code=="TKM"
replace country=	"Tuvalu"  if code==""
replace country=	"Uganda"  if code=="UGA"
replace country=	"Ukraine"  if code=="UKR"
replace country=	"United Arab Emirates"  if code=="ARE"
replace country=	"United Kingdom"  if code=="GBR"
replace country=	"United States of America"  if code=="USA"
replace country=	"Uruguay"  if code=="URY"
replace country=	"Uzbekistan"  if code=="UZB"
replace country=	"Vanuatu"  if code=="VUT"
replace country=	"Venezuela"  if code=="VEN"
replace country=	"Viet Nam"  if code=="VNM"
replace country=	"Yemen"  if code=="YEM"
replace country=	"Zambia"  if code=="ZMB"
replace country=	"Zimbabwe"  if code=="ZWE"

* not used in any other dataset but Babones and Alvarez (2007)
replace country= "Czechoslovakia" if code=="CSK"
replace country= "East Germany" if code=="DEE"
replace country= "West Germany" if code=="DEW"
replace country= "Hong Kong" if code=="HKG"
replace country= "Puerto Rico" if code=="PRI"
replace country= "Yugoslavia" if code=="YUF"

* We couldn't figure out what "SUN" was. But might be one of the developing countries, which is not in our sample anyway.

drop if country=="missing"
drop code
run code
gen match = year*1000 + code
drop country
sort match 
cd "$data"
save gini, replace


* 5. macroeconomic data (growth, development, : WDI)
clear
cd "$dir"
use wdi2011
cd "$data"
keep  year countryname gdppercapitaconstant2000us gdpgrowthannual
rename countryname country
rename gdppercapitaconstant2000us gdppc
rename gdpgrowthannual gdpgro

gen lgdppc = log(gdppc)

keep if year>1990
cd "$dir"
run code.do
cd "$data"
gen match = year*1000 + code
drop country
sort match
save wdi, replace
clear

**********************************************************************************************

Task III. Merging Datasets


* merging these five datasets
* 1. WVS_3_4_5
* 2. polity
* 3. cheibub
* 4. gini (SIID)
* 5. gini2 (SWIID)
* 6. wdi

**************************************************
* country-level data merging first
cd "$data"
clear
use polity
merge match using cheibub
* it seems that Serbia_Montenegro is treated as though it were Yugoslavia in 2001 in Polity.
* to avoid any further problem I just enter the values of Yugoslavia for S&M 2001
replace democ = 7 if match == 2001154
replace autoc = 0 if match == 2001154
replace polity2 = 7 if match == 2001154
replace durable = 1 if match == 2001154




drop _merge
sort match
save merge1, replace


merge match using gini12
drop _merge
sort match
save merge3, replace


merge match using wdi
drop _merge
sort match
save merge4, replace

merge match using gini
drop _merge
sort match
save merge5, replace


drop if year<1990
drop if year>2004

sort match
save countrylevel, replace
 
**************************************************
* now merging with wvs
clear
use wvs_3_4_5
merge match using countrylevel
drop if wave==.
order country year
drop _merge
sort match
save master_1, replace
* this master_1.dta is our master dataset. If our analysis were to be without multiple imputation, this is the end of data prep.



**********************************************************************************************
Task IV: Preparing for Imputation.

* first we drop the Level-2 data as we only impute Level-1 data.
* Level-2 data will be re-merged after imputation is done.
* keeping the variable "id" is critical!

clear
cd "$data"
use master_1
sort match
keep my157 - income id 

* we also drop all the composite indices we create as we impute all the indicators.
drop instconf support antiauth sa
save pre_impute, replace
label data "wvs_3_4_5 for Amelia II"


* run amelia

** you may have to install amelia II from here 
** if you don't have the latest version of R, you may have to install it first, though.
** The links to both Amelia II and R are found here ((http://gking.harvard.edu/amelia/))

* in amelia II, use the file saved above ("pre_impute.dta").
* the only setting that should be done in AMELIA is identifying "id" as an "ID variable".
* it takes up to 20 minutes depending on the computer.

******************************************************************************************

